@@ -19,12 +19,12 @@ import os
 import os.path
 
 PACKAGE    = "sabayon"
-VERSION    = "2.12.4"
-LOCALEDIR = "/gnome/head/INSTALL/share/locale"
-DATADIR    = "/gnome/head/INSTALL/share"
-SYSCONFDIR = "/gnome/head/INSTALL/etc"
-LIBEXECDIR = "/gnome/head/INSTALL/libexec"
-SBINDIR    = "/gnome/head/INSTALL/sbin"
+VERSION    = "2.17.90"
+LOCALEDIR = "/usr/local/share/locale"
+DATADIR    = "/usr/local/share"
+SYSCONFDIR = "/usr/local/etc"
+LIBEXECDIR = "/usr/local/libexec"
+SBINDIR    = "/usr/local/sbin"
 
 GLADEDIR    = os.path.join (DATADIR, "sabayon", "glade")
 PROFILESDIR = os.path.join (SYSCONFDIR, "desktop-profiles")
@@ -52,7 +52,7 @@ NOLOGIN_SHELL = "/sbin/nologin"
 SKEL_HOMEDIR  = "/etc/skel"
 
 XNEST_ARGV   = [ "/usr/bin/Xnest", "-terminate", "-audit", "0", "-nolisten", "tcp" ]
-SESSION_ARGV = [ "/etc/X11/xinit/Xsession", "gnome" ]
+SESSION_ARGV = [ "/etc/opt/gnome/gdm/Xsession", "" ]
 USERMOD_ARGV = [ "/usr/sbin/usermod" ]
 
 PANEL_KEY_BASE = "/apps/panel"
